@@ -100,6 +100,7 @@ void KFileCoderApp::UpdateCommandsAccess()
 	// If archive opened
 	if (doc -> IsArchiveOpened() == TRUE)
 	{	disableCommand(ID_FILE_NEW);
+		disableCommand(ID_FILE_OPEN);
 		disableCommand(ID_FILE_OPEN);
 		enableCommand(ID_FILE_CLOSE);
 		enableCommand(ID_FILE_PROP);
@@ -199,8 +200,9 @@ void KFileCoderApp::initMenuBar()
   ///////////////////////////////////////////////////////////////////
   // menuBar entry help_menu
   help_menu = new QPopupMenu();
-  help_menu = kapp->getHelpMenu(true, i18n(IDS_APP_ABOUT));
-
+  //help_menu = kapp->getHelpMenu(true, i18n(IDS_APP_ABOUT));
+  help_menu->insertItem(i18n("KFileCoder &Home page"), ID_HELP_WEBSITE);
+  help_menu->insertItem(i18n("&About KFileCoder..."), ID_HELP_ABOUT);
 
   ///////////////////////////////////////////////////////////////////
   // MENUBAR CONFIGURATION
@@ -208,6 +210,7 @@ void KFileCoderApp::initMenuBar()
   menuBar()->insertItem(i18n("&File"), file_menu);
   menuBar()->insertItem(i18n("&Edit"), archive_menu);
   menuBar()->insertItem(i18n("&View"), view_menu);
+  menuBar()->insertItem(i18n("&Help"), help_menu);
 
   ///////////////////////////////////////////////////////////////////
   // INSERT YOUR APPLICATION SPECIFIC MENUENTRIES HERE
@@ -223,6 +226,7 @@ void KFileCoderApp::initMenuBar()
   CONNECT_CMD(archive_menu);
   CONNECT_CMD(extract_menu);
   CONNECT_CMD(view_menu);
+  CONNECT_CMD(help_menu);
 
 }
 
@@ -234,15 +238,16 @@ void KFileCoderApp::initToolBar()
   // TOOLBAR
   // set toolBar() the current toolBar and the position due to config file
   toolBar()->insertButton(Icon("filenew.xpm"), ID_FILE_NEW, true, i18n("New File"));
+
   toolBar()->insertButton(Icon("fileopen.xpm"), ID_FILE_OPEN, true, i18n("Open File"));
+  toolBar()->setDelayedPopup(ID_FILE_OPEN, recentPop);
+
   toolBar()->insertSeparator();
   toolBar()->insertButton(Icon("fileprop.xpm"), ID_FILE_PROP, true, i18n("File Properties"));
   toolBar()->insertSeparator();
   toolBar()->insertButton(Icon("add.xpm"), ID_ARCHIVE_ADD, true, i18n("Add"));
   toolBar()->insertButton(Icon("extract.xpm"), ID_ARCHIVE_EXTRACT_ALL, true, i18n("Extract all"));
   toolBar()->insertButton(Icon("delete.xpm"), ID_ARCHIVE_DELETE, true, i18n("Delete"));
-  toolBar()->insertSeparator();
-  toolBar()->insertButton(Icon("help.xpm"), ID_HELP, SIGNAL(pressed()), kapp, SLOT(appHelpActivated()), true, i18n("Help"));
 
   ///////////////////////////////////////////////////////////////////
   // INSERT YOUR APPLICATION SPECIFIC TOOLBARS HERE -e.g. tool_bar_1:
@@ -282,15 +287,15 @@ void KFileCoderApp::initView()
   doc -> SetMainWnd(this);
   doc -> SetListView(view);
 	
-	view -> addColumn(klocale->translate("Name"), 250);
+	view -> addColumn(i18n("Name"), 250);
 	
-	view -> addColumn(klocale->translate("Size"), 100);
+	view -> addColumn(i18n("Size"), 100);
 	view -> setColumnAlignment(1, 2);
 
-	view -> addColumn("CRC", 100);
+	view -> addColumn(i18n("CRC"), 100);
 	view -> setColumnAlignment(2, 2);
 
-	view -> addColumn("Path", 200);
+	view -> addColumn(i18n("Path"), 200);
 
 	view -> setSorting(-1); // Disable sorting for all columns
 	view -> setMultiSelection(TRUE);
@@ -392,7 +397,7 @@ void KFileCoderApp::slotFileOpen()
 	int nRes;
 
 	QFileDialog dlg;
-	strFilename = dlg.getOpenFileName();
+	strFilename = dlg.getOpenFileName("*.kfc");
 	if (strFilename.isEmpty())
 		return ;
 
@@ -403,7 +408,7 @@ void KFileCoderApp::slotFileOpen()
 		return;
 	sprintf (szPassword, "%s", passDlg.GetPassword());
 
-	sprintf (szFilename, "%s", (const char *) strFilename);
+	sprintf (szFilename, "%s", strFilename.data());
 
 	AddRecentFileToList(szFilename);
 
@@ -424,10 +429,18 @@ void KFileCoderApp::slotFileNew()
 	QString strFilename;
 	int nRes;
 	QFileDialog dlg;
-	strFilename = dlg.getSaveFileName();
+	strFilename = dlg.getSaveFileName(0, "*.kfc");
 	if (strFilename.isEmpty())
 		return ;
 
+	// Force the extension to be "kfc"
+	if(strFilename.size() > 3)
+	{	QString strExt = strFilename.right(4);
+		if (strExt != ".kfc" && strExt.right(1) != ".")
+			strFilename += ".kfc";
+	}
+
+
 	// Dialog to ask password ==> szPassword
 	PassDialog passDlg(this, (const char*) 0);
 	nRes = passDlg.exec();
@@ -438,13 +451,16 @@ void KFileCoderApp::slotFileNew()
 	// TODO = Dialog to ask Algorithm to use
 	nAlgorithm = ALGO_ALG1XOR; // TEMPORARY
 
-	sprintf (szFilename, "%s", (const char *) strFilename);
+	sprintf (szFilename, "%s", strFilename.data());
 	AddRecentFileToList(szFilename);
 
 	nRes = doc -> CreateArchive(szFilename, szPassword, nAlgorithm);
 	if (nRes == -1)
 		return;
 	
+	// Propose to add files to archive
+	slotArchiveAdd();
+
 	// Update menu & toolbar commands
 	UpdateCommandsAccess();
 }
@@ -613,7 +629,7 @@ void KFileCoderApp::slotOpenRecent(int i)
 		return;
 	sprintf (szPassword, "%s", passDlg.GetPassword());
 
-	sprintf (szFilename, "%s", (const char *) strFilename);
+	sprintf (szFilename, "%s", strFilename.data());
 	nRes = doc -> OpenArchive(szFilename, szPassword);
 	if (nRes == -1)
 		return;
@@ -622,6 +638,35 @@ void KFileCoderApp::slotOpenRecent(int i)
 	UpdateCommandsAccess();
 }					
 
+// ===========================================================================================================================
+void KFileCoderApp::slotHelpWebSite()
+{	if(vfork() > 0)
+	{ // drop setuid, setgid
+    setgid(getgid());
+    setuid(getuid());
+
+    execlp("kfmclient", "kfmclient", "exec", QString("http://perso.club-internet.fr/dupoux/sysexp/linux/kfilecod/").data(), 0);
+    _exit(0);
+  }
+}
+
+// ===========================================================================================================================
+void KFileCoderApp::slotHelpAbout()
+{
+  QMessageBox aboutmsg(this, "About KFileCoder");
+  aboutmsg.setCaption(i18n("About KFileCoder..."));
+  aboutmsg.setButtonText(1, i18n("OK"));
+  aboutmsg.setText("\t           KFileCoder version "VERSION" \n\n\n"
+                   "Franois Dupoux <fdupoux@lemel.fr>\n\n"
+                   "http://perso.club-internet.fr/dupoux/sysexp/linux/kfilecod/\n");
+
+  QPixmap pm;
+  pm.load(KApplication::kde_datadir() + "/kfilecoder/pics/about.bmp");
+  aboutmsg.setIconPixmap(pm);
+  aboutmsg.show();
+
+}
+
 // ===========================================================================================================================
 void KFileCoderApp::AddRecentFileToList(char *szFilename)
 {
@@ -665,6 +710,9 @@ void KFileCoderApp::commandCallback(int id_)
   
     ON_CMD(ID_VIEW_TOOLBAR,             slotViewToolBar())
     ON_CMD(ID_VIEW_STATUSBAR,           slotViewStatusBar())
+
+    ON_CMD(ID_HELP_WEBSITE,             slotHelpWebSite())
+    ON_CMD(ID_HELP_ABOUT,               slotHelpAbout())
   }
 }
 
@@ -687,6 +735,9 @@ void KFileCoderApp::statusCallback(int id_)
 
     ON_STATUS_MSG(ID_VIEW_TOOLBAR,         i18n("Enables / disables the actual Toolbar"))
     ON_STATUS_MSG(ID_VIEW_STATUSBAR,       i18n("Enables / disables the Statusbar"))
+
+    ON_STATUS_MSG(ID_HELP_WEBSITE,         i18n("Go to KFileCoder Home Page"))
+    ON_STATUS_MSG(ID_HELP_ABOUT,           i18n("Draw informations about program"))
   }
 }
 
